// DTActivityController.h
// Created by Rob Rix on 2011-04-14
// Copyright 2011 DEVONtechnologies, LLC

#import <Cocoa/Cocoa.h>

@class DTActivityLog;

@interface DTActivityWindow : NSPanel
{
@private
	IBOutlet NSView *activityLogView;
	BOOL byUser;
}

-(BOOL)byUser;
-(NSSize)preferredSize;
-(IBAction)orderFrontActivityPanel:(id)sender;

@end

#define DTActivityController					DTActivityWindowController
#define DTActivityControllerClassFromString()	NSClassFromString(@"DTActivityWindowController")

@interface DTActivityController : NSWindowController
{
@private
	NSMutableArray *logKeys;
	NSMutableDictionary *logs;
	IBOutlet NSView *activityLogView;
	IBOutlet NSCollectionView *activityCollectionView;
}

+(BOOL)isVisible;
+(void)close;
+(DTActivityController *)sharedController;

-(NSArray *)logs;
-(NSUInteger)count;

-(DTActivityLog *)logForKey:(id)key;
-(void)setLog:(DTActivityLog *)log forKey:(id)key;
-(void)setLog:(DTActivityLog *)log forKey:(id)key showWindow:(BOOL)showWindow;
-(DTActivityLog *)addLogForKey:(id)key title:(NSString *)title showWindow:(BOOL)showWindow; // Creates a new log only if necessary

-(void)removeLogForKey:(id)key;
-(void)removeLogForKey:(id)key orderOut:(BOOL)orderOut;

@end

@protocol DTActivityControllerDelegate // Implemented by application delegate

@optional
-(void)controller:(DTActivityController *)controller didAddLogForKey:(id)key;
-(BOOL)controller:(DTActivityController *)controller showWindowForKey:(id)key;
-(void)controller:(DTActivityController *)controller didRemoveLogForKey:(id)key;
-(BOOL)controller:(DTActivityController *)controller orderOutForKey:(id)key;

@end

@interface NSObject (DTActivityController_AppDelegate)

@end

@interface DTActivityView : NSView
{
@private
	int _settingFrameSize;
}

@end

@interface DTActivityCollectionView : NSCollectionView
{
@private
	int _settingFrameSize;
}

@end

@interface DTActivityPane : NSViewController
{
@private
	IBOutlet NSView *activityLogView;
	IBOutlet DTActivityCollectionView *activityCollectionView;
}

-(DTActivityController *)controller;
-(NSCollectionView *)collectionView;
-(NSArray *)logs;

@end


